//*****************************************************************************
//*****************************************************************************
//  FILENAME:  `@LIB_NAME`_Attenuator.c
//  Version: 1.0, Updated on 2005/09/08 at 20:14:34
//  Application: PSoC Express 2.0
//
//  DESCRIPTION:  This Driver calls the low level driver and returns the
//                voltage that corresponds to a given channel.
//
//-----------------------------------------------------------------------------
//      Copyright (c) Cypress MicroSystems 2004. All Rights Reserved.
//*****************************************************************************
//*****************************************************************************

#include "m8c.h"
#include "`@LIB_NAME`_Attenuator.h"
#include "cmx.h"
#include "calibration.h"

// Channel type header file
#include "CMX_MVOLTS_IN_CHAN.h"



//-----------------------------------------------------------------------------
//  FUNCTION NAME: Attenuator_Instantiate(const `@LIB_NAME`_Attenuator_ParameterBlock * thisBLK)
//
//  DESCRIPTION:  
//    This function doesn't do anything at this time, but is placed here
//    for forward compatibility.
//
//-----------------------------------------------------------------------------
//
//  ARGUMENTS: 
//    thisBLK  => Pointer to ParameterBlock for this instance.
//
//  RETURNS: None
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE: 
//
//-----------------------------------------------------------------------------
void `@LIB_NAME`_Attenuator_Instantiate(const `@LIB_NAME`_Attenuator_ParameterBlock * thisBLK)
{
   // Blank function
   
}

//-----------------------------------------------------------------------------
//  FUNCTION NAME: Attenuator_GetValue(const `@LIB_NAME`_Attenuator_ParameterBlock * thisBLK)
//
//  DESCRIPTION:  
//	This function returns a current value of input voltage.
//         
//-----------------------------------------------------------------------------
//
//  ARGUMENTS: 
//    thisBLK  => Pointer to ParameterBlock for this instance.
//
//  RETURNS:   A unsigned integer value (two bytes) of input voltage(in milivolts).
//
//  SIDE EFFECTS: 
//
//  THEORY of OPERATION or PROCEDURE: 
//
//  The voltage output is scaled by using the ScaleNumerator and ScaleDenominator
//  in the parameter block.
//
//-----------------------------------------------------------------------------

int  `@LIB_NAME`_Attenuator_GetValue(const `@LIB_NAME`_Attenuator_ParameterBlock * thisBLK)
{
	BYTE bChan;
	long  lmVolts;

	bChan = thisBLK->InPort;                  // Get channel from PB
	lmVolts = (long)iGetChanMVolts(bChan);
	
	
	lmVolts = lmVolts * thisBLK->Upper_Voltage_Limit;
	lmVolts = lmVolts>>10;
	
	lmVolts += imVolts_Chan_Offset[bChan];   // Add user calibration offset
	return((int)lmVolts);                    // Convert to mVolts and return
}
