//----------------------------------------------------------------------------
// C main line
//----------------------------------------------------------------------------

#include <m8c.h>          // part specific constants and macros
#include "PSoCAPI.h"      // PSoC API definitions for all User Modules

#include "driverdecl.h"
#include "CMXSystem.h"
#include "CMXSystemExtern.h"
#include "TransferFunction.h"

#include "cmx.h"
#include "ProjectProperties.h"
#include "Custom.h"

// Channel includes
// ADC_00 Include
#include "CMX_ADC_CHAN.h"
// LCD_SHARED_01 Include
#include "cmx_lcd_chan.h"

void main()
{
    // Initialize Project
    M8C_EnableGInt;                            // Turn on interrupts 
    I2C_CFG &= 0xFC;                           // Disable I2C in case it's not used.
    SystemTimer_Start();
    SystemTimer_SetInterval(SystemTimer_64_HZ);
    SystemTimer_EnableInt();

    // Initialize Channels
    // ADC_00 Initialization  
    ADCBUF_Start(3); // Power up ADC Buffer PGA
    ADC_Start(3); // Power up ADC
    AdcScanReset(); // Initialize ADC scanner
    ADC_GetSamples(0); // Turn on GetSamples
    // LCD_SHARED_01 Initialization
    LCDStartSharedChan();

    // Initialize Variables
	SystemVars.ReadOnlyVars.pse_ADC = 0;
	SystemVars.ReadOnlyVars.pse_D1 = 0;
	SystemVars.ReadOnlyVars.pse_D10 = 0;
	SystemVars.ReadOnlyVars.pse_D11 = 0;
	SystemVars.ReadOnlyVars.pse_D12 = 0;
	SystemVars.ReadOnlyVars.pse_D13 = 0;
	SystemVars.ReadOnlyVars.pse_D14 = 0;
	SystemVars.ReadOnlyVars.pse_D2 = 0;
	SystemVars.ReadOnlyVars.pse_D3 = 0;
	SystemVars.ReadOnlyVars.pse_D4 = 0;
	SystemVars.ReadOnlyVars.pse_D5 = 0;
	SystemVars.ReadOnlyVars.pse_D6 = 0;
	SystemVars.ReadOnlyVars.pse_D7 = 0;
	SystemVars.ReadOnlyVars.pse_D8 = 0;
	SystemVars.ReadOnlyVars.pse_D9 = 0;
	SystemVars.ReadOnlyVars.pse_LCD_VAL = 0;

    // Driver instantiations
CMX_DIO_Instantiate(&pse_D9);
CMX_DIO_SetValue(&pse_D9, (BYTE)SystemVars.ReadOnlyVars.pse_D9);
CMX_DIO_Instantiate(&pse_D10);
CMX_DIO_SetValue(&pse_D10, (BYTE)SystemVars.ReadOnlyVars.pse_D10);
CMX_DIO_Instantiate(&pse_D11);
CMX_DIO_SetValue(&pse_D11, (BYTE)SystemVars.ReadOnlyVars.pse_D11);
CMX_DIO_Instantiate(&pse_D12);
CMX_DIO_SetValue(&pse_D12, (BYTE)SystemVars.ReadOnlyVars.pse_D12);
CMX_DIO_Instantiate(&pse_D13);
CMX_DIO_SetValue(&pse_D13, (BYTE)SystemVars.ReadOnlyVars.pse_D13);
CMX_DIO_Instantiate(&pse_D14);
CMX_DIO_SetValue(&pse_D14, (BYTE)SystemVars.ReadOnlyVars.pse_D14);
CMX_DIO_Instantiate(&pse_D1);
CMX_DIO_SetValue(&pse_D1, (BYTE)SystemVars.ReadOnlyVars.pse_D1);
CMX_DIO_Instantiate(&pse_D2);
CMX_DIO_SetValue(&pse_D2, (BYTE)SystemVars.ReadOnlyVars.pse_D2);
CMX_DIO_Instantiate(&pse_D3);
CMX_DIO_SetValue(&pse_D3, (BYTE)SystemVars.ReadOnlyVars.pse_D3);
CMX_DIO_Instantiate(&pse_D4);
CMX_DIO_SetValue(&pse_D4, (BYTE)SystemVars.ReadOnlyVars.pse_D4);
CMX_DIO_Instantiate(&pse_D5);
CMX_DIO_SetValue(&pse_D5, (BYTE)SystemVars.ReadOnlyVars.pse_D5);
CMX_DIO_Instantiate(&pse_D6);
CMX_DIO_SetValue(&pse_D6, (BYTE)SystemVars.ReadOnlyVars.pse_D6);
CMX_DIO_Instantiate(&pse_D7);
CMX_DIO_SetValue(&pse_D7, (BYTE)SystemVars.ReadOnlyVars.pse_D7);
CMX_DIO_Instantiate(&pse_D8);
CMX_DIO_SetValue(&pse_D8, (BYTE)SystemVars.ReadOnlyVars.pse_D8);
CMX_LCDNVU_Instantiate(&pse_LCD_VAL);
CMX_Attenuator_Instantiate(&pse_ADC);

    // Custom initization code.
    CustomInit();
    // End Initialize Project

	while(1)
	{
        // Sync loop sample rate
#if ( SAMPLE_DIVIDER  )
        SystemTimer_SyncWait(SAMPLE_DIVIDER, SystemTimer_WAIT_RELOAD);
#endif

		// update input variables
		SystemVars.ReadOnlyVars.pse_ADC = CMX_Attenuator_GetValue(&pse_ADC);

        // Custom Post Input function
        CustomPostInputUpdate();

		// run transfer function and update output variables
		TransferFunction();

        // CustomPreOutputUpdate();
        CustomPreOutputUpdate();

		// set outputs
		CMX_DIO_SetValue(&pse_D1, (BYTE)SystemVars.ReadOnlyVars.pse_D1);
		CMX_DIO_SetValue(&pse_D10, (BYTE)SystemVars.ReadOnlyVars.pse_D10);
		CMX_DIO_SetValue(&pse_D11, (BYTE)SystemVars.ReadOnlyVars.pse_D11);
		CMX_DIO_SetValue(&pse_D12, (BYTE)SystemVars.ReadOnlyVars.pse_D12);
		CMX_DIO_SetValue(&pse_D13, (BYTE)SystemVars.ReadOnlyVars.pse_D13);
		CMX_DIO_SetValue(&pse_D14, (BYTE)SystemVars.ReadOnlyVars.pse_D14);
		CMX_DIO_SetValue(&pse_D2, (BYTE)SystemVars.ReadOnlyVars.pse_D2);
		CMX_DIO_SetValue(&pse_D3, (BYTE)SystemVars.ReadOnlyVars.pse_D3);
		CMX_DIO_SetValue(&pse_D4, (BYTE)SystemVars.ReadOnlyVars.pse_D4);
		CMX_DIO_SetValue(&pse_D5, (BYTE)SystemVars.ReadOnlyVars.pse_D5);
		CMX_DIO_SetValue(&pse_D6, (BYTE)SystemVars.ReadOnlyVars.pse_D6);
		CMX_DIO_SetValue(&pse_D7, (BYTE)SystemVars.ReadOnlyVars.pse_D7);
		CMX_DIO_SetValue(&pse_D8, (BYTE)SystemVars.ReadOnlyVars.pse_D8);
		CMX_DIO_SetValue(&pse_D9, (BYTE)SystemVars.ReadOnlyVars.pse_D9);
		CMX_LCDNVU_SetValue(&pse_LCD_VAL, (int)SystemVars.ReadOnlyVars.pse_LCD_VAL);

	}
}
